
<!-- The badges --> 
<!--  TODO!!!
<p align="center">
#   <a href="https://pypi.org/project/rlberry/">
#      <img alt="Python Version" src="https://img.shields.io/badge/python-3.11-blue">
#   </a>
#   <a href="https://img.shields.io/github/contributors/rlberry-py/rlberry">
#      <img alt="contributors" src="https://img.shields.io/github/contributors/rlberry-py/rlberry">
#   </a>
#   <a href="https://codecov.io/gh/rlberry-py/rlberry">
#      <img alt="codecov" src="https://codecov.io/gh/rlberry-py/rlberry/branch/main/graph/badge.svg?token=TIFP7RUD75">
#     </a>
#</p>
#![](https://img.shields.io/codecov/c/github/rlberry-py/rlberry-scool)
-->  


# rlberry-scool
Teaching Reinforcement Learning made easy.
